CronetStreamedResponse class

An HTTP response from the Cronet network stack.

The response body is received asynchronously after the headers have been received.

Properties

contentLength int?
The size of the response body, in bytes.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
The HTTP headers returned by the server.
finalinherited
isRedirect bool
finalinherited
negotiatedProtocol String
The protocol (for example 'quic/1+spdy/3') negotiated with the server.
no setter
persistentConnection bool
Whether the server requested that a persistent connection be maintained.
finalinherited
reasonPhrase String?
The reason phrase associated with the status code.
finalinherited
receivedByteCount int
The minimum count of bytes received from the network to process this request.
no setter
request → BaseRequest?
The (frozen) request that triggered this response.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
The HTTP status code for this response.
finalinherited
stream → ByteStream
The stream from which the response body data can be read.
finalinherited
url Uri
The Uri of the response returned by the server.
finalinherited
wasCached bool
Whether the response came from the cache.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited