NSURLSessionResponseDisposition enum

Inheritance
Available extensions

Values

NSURLSessionResponseCancel → const NSURLSessionResponseDisposition

Cancel the load, this is the same as -task cancel

const NSURLSessionResponseDisposition(0)
NSURLSessionResponseAllow → const NSURLSessionResponseDisposition

Allow the load to continue

const NSURLSessionResponseDisposition(1)
NSURLSessionResponseBecomeDownload → const NSURLSessionResponseDisposition

Turn this request into a download

const NSURLSessionResponseDisposition(2)
NSURLSessionResponseBecomeStream → const NSURLSessionResponseDisposition

Turn this task into a stream task

const NSURLSessionResponseDisposition(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) NSURLSessionResponseDisposition

Constants

values → const List<NSURLSessionResponseDisposition>
A constant List of the values in this enum, in order of their declaration.