priority property

double get priority

The relative priority 0, 1 that the host should use to handle the request.

See NSURLSessionTask.priority

Implementation

double get priority => _nsObject.priority;
set priority (double value)

The relative priority 0, 1 that the host should use to handle the request.

See NSURLSessionTask.priority

Implementation

set priority(double value) => _nsObject.priority = value;