CupertinoAdapter class
A HttpClientAdapter for Dio which delegates HTTP requests
to the native platform by making use of
cupertino_http.
Constructors
- CupertinoAdapter(URLSessionConfiguration configuration)
Properties
- adapter → ConversionLayerAdapter
-
The underlying conversion layer adapter.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
{bool force = false}) → void - Close the current adapter and its inner clients or requests.
-
fetch(
RequestOptions options, Stream< Uint8List> ? requestStream, Future? cancelFuture) → Future<ResponseBody> - Implement this method to make real HTTP requests.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited