NSURLRequestNetworkServiceType enum
! @enum NSURLRequestNetworkServiceType
@discussion The NSURLRequestNetworkServiceType enum defines constants that can be used to specify the service type to associate with this request. The service type is used to provide the networking layers a hint of the purpose of the request.
@constant NSURLNetworkServiceTypeDefault Is the default value for an NSURLRequest when created. This value should be left unchanged for the vast majority of requests.
@constant NSURLNetworkServiceTypeVoIP Specifies that the request is for voice over IP control traffic.
@constant NSURLNetworkServiceTypeVideo Specifies that the request is for video traffic.
@constant NSURLNetworkServiceTypeBackground Specifies that the request is for background traffic (such as a file download).
@constant NSURLNetworkServiceTypeVoice Specifies that the request is for voice data.
@constant NSURLNetworkServiceTypeResponsiveData Specifies that the request is for responsive (time sensitive) data.
@constant NSURLNetworkServiceTypeAVStreaming Specifies that the request is streaming audio/video data.
@constant NSURLNetworkServiceTypeResponsiveAV Specifies that the request is for responsive (time sensitive) audio/video data.
@constant NSURLNetworkServiceTypeCallSignaling Specifies that the request is for call signaling.
Values
- NSURLNetworkServiceTypeDefault → const NSURLRequestNetworkServiceType
-
Standard internet traffic
const NSURLRequestNetworkServiceType(0) - NSURLNetworkServiceTypeVoIP → const NSURLRequestNetworkServiceType
-
Voice over IP control traffic
const NSURLRequestNetworkServiceType(1) - NSURLNetworkServiceTypeVideo → const NSURLRequestNetworkServiceType
-
Video traffic
const NSURLRequestNetworkServiceType(2) - NSURLNetworkServiceTypeBackground → const NSURLRequestNetworkServiceType
-
Background traffic
const NSURLRequestNetworkServiceType(3) - NSURLNetworkServiceTypeVoice → const NSURLRequestNetworkServiceType
-
Voice data
const NSURLRequestNetworkServiceType(4) - NSURLNetworkServiceTypeResponsiveData → const NSURLRequestNetworkServiceType
-
Responsive data
const NSURLRequestNetworkServiceType(6) - NSURLNetworkServiceTypeAVStreaming → const NSURLRequestNetworkServiceType
-
Multimedia Audio/Video Streaming
const NSURLRequestNetworkServiceType(8) - NSURLNetworkServiceTypeResponsiveAV → const NSURLRequestNetworkServiceType
-
Responsive Multimedia Audio/Video
const NSURLRequestNetworkServiceType(9) - NSURLNetworkServiceTypeCallSignaling → const NSURLRequestNetworkServiceType
-
Call Signaling
const NSURLRequestNetworkServiceType(11)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → NSURLRequestNetworkServiceType
Constants
-
values
→ const List<
NSURLRequestNetworkServiceType> - A constant List of the values in this enum, in order of their declaration.