NSURLSessionMultipathServiceType enum
! @enum NSURLSessionMultipathServiceType
@discussion The NSURLSessionMultipathServiceType enum defines constants that can be used to specify the multipath service type to associate an NSURLSession. The multipath service type determines whether multipath TCP should be attempted and the conditions for creating and switching between subflows. Using these service types requires the appropriate entitlement. Any connection attempt will fail if the process does not have the required entitlement. A primary interface is a generally less expensive interface in terms of both cost and power (such as WiFi or ethernet). A secondary interface is more expensive (such as 3G or LTE).
@constant NSURLSessionMultipathServiceTypeNone Specifies that multipath tcp should not be used. Connections will use a single flow. This is the default value. No entitlement is required to set this value.
@constant NSURLSessionMultipathServiceTypeHandover Specifies that a secondary subflow should only be used when the primary subflow is not performing adequately. Requires the com.apple.developer.networking.multipath entitlement.
@constant NSURLSessionMultipathServiceTypeInteractive Specifies that a secondary subflow should be used if the primary subflow is not performing adequately (packet loss, high round trip times, bandwidth issues). The secondary subflow will be created more aggressively than with NSURLSessionMultipathServiceTypeHandover. Requires the com.apple.developer.networking.multipath entitlement.
@constant NSURLSessionMultipathServiceTypeAggregate Specifies that multiple subflows across multiple interfaces should be used for better bandwidth. This mode is only available for experimentation on devices configured for development use. It can be enabled in the Developer section of the Settings app.
Values
- NSURLSessionMultipathServiceTypeNone → const NSURLSessionMultipathServiceType
-
None - no multipath (default)
const NSURLSessionMultipathServiceType(0) - NSURLSessionMultipathServiceTypeHandover → const NSURLSessionMultipathServiceType
-
Handover - secondary flows brought up when primary flow is not performing adequately.
const NSURLSessionMultipathServiceType(1) - NSURLSessionMultipathServiceTypeInteractive → const NSURLSessionMultipathServiceType
-
Interactive - secondary flows created more aggressively.
const NSURLSessionMultipathServiceType(2) - NSURLSessionMultipathServiceTypeAggregate → const NSURLSessionMultipathServiceType
-
Aggregate - multiple subflows used for greater bandwidth.
const NSURLSessionMultipathServiceType(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → NSURLSessionMultipathServiceType
Constants
-
values
→ const List<
NSURLSessionMultipathServiceType> - A constant List of the values in this enum, in order of their declaration.